==> csircd-1.13.tar.gz: csircd-1.13/confparse/conftest.c <==
/*
**   Generic Config file parser (conftest.c)
**   Copyright (C) 1999 Fred Jacobs, Chris Behrens
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 1, or (at your option)
**   any later version.
**
**   This program is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with this program; if not, write to the Free Software
**   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
**  The idea of something this generic came solely from Fred Jacobs.
**  I completely rewrote his implementation, however, although some
**  pieces remain similar.  Thank you very much, Fred! :)
**    - Chris
*/

#include <stdio.h>
#include "configparse.h"


static void conftest_entry_print(CONFIGENTRY *ce, int deep);
static void conftest_print(CONFIGFILE *cfptr);

static void conftest_entry_print(CONFIGENTRY *ce, int deep)
{
	int num = 0;

	if (ce)
		printf("%*sNew section at line %i of %s:\n", deep*3, "", ce->ce_prevlevel ? ce->ce_prevlevel->ce_sectlinenum : 0, ce->ce_fileptr->cf_filename);
	for(;ce;ce=ce->ce_next)
	{
		num++;
		if (!ce->ce_varname && !ce->ce_vardata && !ce->ce_entries)
			continue;
		if (ce->ce_varname)
		{
			printf("%*sName: %s (Linenumber %i of %s)\n", 2+deep*3, "",
				ce->ce_varname, ce->ce_varlinenum,
				ce->ce_fileptr->cf_filename);
			if (ce->ce_vardata)
				printf("%*sData: %s\n", 2+deep*3, "", ce->ce_vardata);
		}
		if (ce->ce_entries)
		{
			conftest_entry_print(ce->ce_entries, deep+1);
		}
	}
	if (num)
		printf("%*sEnd section\n", deep*3, "");
}

static void conftest_print(CONFIGFILE *cfptr)
{
	for(;cfptr;cfptr=cfptr->cf_next)
		conftest_entry_print(cfptr->cf_entries, 0);
}

int main(int argc, char **argv)
{
	CONFIGFILE	*cfptr;

	if (argc < 2)
	{
		fprintf(stderr, "Usage: conftest conffile\n");
		exit(-1);
	}

	cfptr = config_load(argv[1]);

	if (cfptr)
	{
		printf("Conf loaded without errors\n");
#ifdef DOIT
		{
			int i;

			printf("sleeping\n");
			sleep(10);
			for(i=0;i<1000;i++)
				config_free(config_load(argv[1]));
		}
#else
		conftest_print(cfptr);
#endif
		config_free(cfptr);
		sleep(5);
		printf("sleeping\n");
	}
	else
		printf("Conf could not be loaded\n");
	exit(0);
}

==> csircd-1.14.tar.gz: csircd-1.14/confparse/conftest.c <==
/*
**   Generic Config file parser (conftest.c)
**   Copyright (C) 1999 Fred Jacobs, Chris Behrens
**
**   This program is free software; you can redistribute it and/or modify
**   it under the terms of the GNU General Public License as published by
**   the Free Software Foundation; either version 1, or (at your option)
**   any later version.
**
**   This program is distributed in the hope that it will be useful,
**   but WITHOUT ANY WARRANTY; without even the implied warranty of
**   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**   GNU General Public License for more details.
**
**   You should have received a copy of the GNU General Public License
**   along with this program; if not, write to the Free Software
**   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/*
**  The idea of something this generic came solely from Fred Jacobs.
**  I completely rewrote his implementation, however, although some
**  pieces remain similar.  Thank you very much, Fred! :)
**    - Chris
*/

#include <stdio.h>
#include <stdlib.h>
#include <stdarg.h>
#include <unistd.h>
#include <syslog.h>
#include "configparse.h"


static void conftest_entry_print(CONFIGENTRY *ce, int deep);
static void conftest_print(CONFIGFILE *cfptr);
static void conftest_log_func(int level, const char *format, ...);

static void conftest_entry_print(CONFIGENTRY *ce, int deep)
{
	int num = 0;

	if (ce)
		printf("%*sNew section at line %i of %s:\n", deep*3, "", ce->ce_prevlevel ? ce->ce_prevlevel->ce_sectlinenum : 0, ce->ce_fileptr->cf_filename);
	for(;ce;ce=ce->ce_next)
	{
		num++;
		if (!ce->ce_varname && !ce->ce_vardata && !ce->ce_entries)
			continue;
		if (ce->ce_varname)
		{
			printf("%*sName: %s (Linenumber %i of %s)\n", 2+deep*3, "",
				ce->ce_varname, ce->ce_varlinenum,
				ce->ce_fileptr->cf_filename);
			if (ce->ce_vardata)
				printf("%*sData: %s\n", 2+deep*3, "", ce->ce_vardata);
		}
		if (ce->ce_entries)
		{
			conftest_entry_print(ce->ce_entries, deep+1);
		}
	}
	if (num)
		printf("%*sEnd section\n", deep*3, "");
}

static void conftest_print(CONFIGFILE *cfptr)
{
	for(;cfptr;cfptr=cfptr->cf_next)
		conftest_entry_print(cfptr->cf_entries, 0);
}

static void conftest_log_func(int level, const char *format, ...)
{
	va_list		ap;

	va_start(ap, format);
	if (level == LOG_NOTICE)
		fprintf(stderr, "[NOTICE] ");
	else if (level == LOG_ERR)
		fprintf(stderr, "[ERROR] ");
	vfprintf(stderr, format, ap);
	va_end(ap);
}

int main(int argc, char **argv)
{
	CONFIGFILE	*cfptr;

	if (argc < 2)
	{
		fprintf(stderr, "Usage: conftest conffile\n");
		exit(-1);
	}

	cfptr = config_load(argv[1], conftest_log_func);

	if (cfptr)
	{
		printf("Conf loaded without errors\n");
#ifdef DOIT
		{
			int i;

			printf("sleeping\n");
			sleep(10);
			for(i=0;i<1000;i++)
				config_free(config_load(argv[1]));
		}
#else
		conftest_print(cfptr);
#endif
		config_free(cfptr);
		printf("sleeping\n");
		sleep(5);
	}
	else
		printf("Conf could not be loaded\n");
	exit(0);
}
